@@ -1,6 +1,4 @@
-"""
-    Does foo.svg --> foo.pdf with no change to the file.
-"""
+"""Does foo.svg --> foo.pdf with no change to the file."""
 
 from __future__ import annotations
 
@@ -10,6 +8,8 @@ from typing import TYPE_CHECKING
 from sphinx.transforms.post_transforms.images import ImageConverter
 
 if TYPE_CHECKING:
+    import os
+
     from sphinx.application import Sphinx
     from sphinx.util.typing import ExtensionMetadata
 
@@ -22,7 +22,9 @@ class MyConverter(ImageConverter):
     def is_available(self) -> bool:
         return True
 
-    def convert(self, _from: str, _to: str) -> bool:
+    def convert(
+        self, _from: str | os.PathLike[str], _to: str | os.PathLike[str]
+    ) -> bool:
         """Mock converts the image from SVG to PDF."""
         shutil.copyfile(_from, _to)
         return True
